/* DocViewAstro.h
 * Astrology Additions for DocView
 *
 * Copyright (C) 1998-2006 by Cenon GmbH
 * Author:   Georg Fleischmann
 *
 * created:  1998-12-19
 * modified: 2006-04-21
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the Cenon Public License as
 * published by Cenon GmbH. Among other things, the
 * License requires that the copyright notices and this notice
 * be preserved on all copies.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the Cenon Public License for more details.
 *
 * You should have received a copy of the Cenon Public License along
 * with this program; see the file LICENSE. If not, write to Cenon.
 *
 * Cenon GmbH, Schwabstr. 45, 72108 Rottenburg a.N., Germany
 * eMail: info@cenon.de
 * http://www.cenon.info
 */

#ifndef CEN_H_DOCVIEWASTRO
#define CEN_H_DOCVIEWASTRO

#include "../Cenon/DocView.h"

@interface DocView(Astro)
- (NSCalendarDate*)sideralTime:(NSCalendarDate*)gmt longitude:(float)l;
- (float)mc:(NSCalendarDate*)sideralTime;
- (float)ac:(NSCalendarDate*)sideralTime latitude:(float)lat;

- (void)setCrossAt:(NSPoint)p layer:(int)layer;
@end

#endif // CEN_H_DOCVIEWASTRO
